==> trilinos_9.0.3.dfsg.orig.tar.gz: trilinos-9.0.3.dfsg.orig/packages/Sundance/src-std-framework/Assembly/SundanceLocalMatrixContainer.cpp <==
/* @HEADER@ */
// ************************************************************************
// 
//                              Sundance
//                 Copyright (2005) Sandia Corporation
// 
// Copyright (year first published) Sandia Corporation.  Under the terms 
// of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government 
// retains certain rights in this software.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//                                                                                 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA                                                                                
// Questions? Contact Kevin Long (krlong@sandia.gov), 
// Sandia National Laboratories, Livermore, California, USA
// 
// ************************************************************************
/* @HEADER@ */

#include "SundanceLocalMatrixContainer.hpp"
#include "SundanceOut.hpp"
#include "SundanceTabs.hpp"


using namespace SundanceStdFwk;
using namespace SundanceStdFwk::Internal;



LocalMatrixContainer::LocalMatrixContainer(const Array<int>& isTwoForm,
                                           const Array<Array<int> >& testID,
                                           const Array<Array<int> >& unkID,
                                           const Array<Array<double> >& coeffs)
  : isTwoForm_(isTwoForm),
    testID_(testID),
    unkID_(unkID),
    coeffs_(coeffs)
{
  for (unsigned int i=workspace().size(); i<isTwoForm.size(); i++)
    {
      workspace().append(rcp(new Array<double>()));
      workspace()[i]->reserve(1000);
    }
}

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/Sundance/src-std-framework/Assembly/SundanceLocalMatrixContainer.cpp <==
/* @HEADER@ */
// ************************************************************************
// 
//                              Sundance
//                 Copyright (2005) Sandia Corporation
// 
// Copyright (year first published) Sandia Corporation.  Under the terms 
// of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government 
// retains certain rights in this software.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//                                                                                 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA                                                                                
// Questions? Contact Kevin Long (krlong@sandia.gov), 
// Sandia National Laboratories, Livermore, California, USA
// 
// ************************************************************************
/* @HEADER@ */

#include "SundanceLocalMatrixContainer.hpp"
#include "SundanceOut.hpp"
#include "SundanceTabs.hpp"


using namespace Sundance;
using namespace Sundance;



LocalMatrixContainer::LocalMatrixContainer(const Array<int>& isTwoForm,
                                           const Array<Array<int> >& testID,
                                           const Array<Array<int> >& unkID,
                                           const Array<Array<double> >& coeffs)
  : isTwoForm_(isTwoForm),
    testID_(testID),
    unkID_(unkID),
    coeffs_(coeffs)
{
  for (int i=workspace().size(); i<isTwoForm.size(); i++)
    {
      workspace().append(rcp(new Array<double>()));
      workspace()[i]->reserve(1000);
    }
}
